@@ -33,6 +33,9 @@ mod template;
 #[cfg(feature = "cli")]
 mod transport;
 
+#[cfg(test)]
+use prelude::*;
+
 #[cfg(feature = "cli")]
 pub use error::{Error, LogError, RunErrorLocal};
 
@@ -95,3 +98,8 @@ pub fn logger() {
         .map_err(LogError::from)
         .unwrap();
 }
+
+#[cfg(test)]
+fn add_port(port: u16) -> SocketAddr {
+    SocketAddr::from(([0, 0, 0, 0], port))
+}
